"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const common_1 = require("../lib/common");
const abap_1 = require("../lib/abap");
const main_1 = require("../main");
class Pretty extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Pretty);
        try {
            const { objectType = "", objectName = "" } = args;
            const client = await common_1.getClient(flags);
            const main = new main_1.Main(client);
            const objects = await abap_1.list(client, objectType, objectName, message => cli_ux_1.cli.action.start(message), flags.recursive);
            cli_ux_1.cli.action.stop("Done");
            await main.processObjects(objects, {
                test: false,
                transport: flags.transport
            });
        }
        catch (error) {
            this.log(error.toString());
        }
    }
}
exports.default = Pretty;
Pretty.description = "Pretty prints every supported include file in the selected range";
Pretty.examples = [
    "$ abapPretty prettyprint -c MYCONN DEVC/K ZMYPACKAGE",
    "$ abapPretty prettyprint -h host -P port -u user -p password DEVC/K ZMYPACKAGE -t transportnumber",
    `$ SAP_ASHOST=host SAP_PORT=port SAP_USER=user SAP_PASSWORD=bash -c 'abapPretty prettyprint DEVC/K ZMYPACKAGE'`
];
Pretty.flags = common_1.ALLCOMMONFLAGS;
Pretty.args = common_1.COMMONARGS;
